==> ffmpeg-normalize-dmo_1.37.2.orig.tar.xz: ffmpeg-normalize-1.37.2/CHANGELOG.md <==
## [1.37.2] - 2026-02-04

### 🚀 Features

- Better preset listing

### ⚙️ Miscellaneous Tasks

- Bump version to 1.37.2
## [1.37.1] - 2026-02-04

### ⚙️ Miscellaneous Tasks

- Bump version to 1.37.1
## [1.37.0] - 2026-02-03

### 🐛 Bug Fixes

- Update Claude workflows for fork PR permissions

### 📚 Documentation

- Update API examples

### ⚙️ Miscellaneous Tasks

- Update contriburors
- Bump version to 1.37.0
## [1.36.1] - 2026-01-07

### 🚀 Features

- Better file validation

### 📚 Documentation

- Typo
- Move quickstart before what's new section

### ⚙️ Miscellaneous Tasks

- Update support to python 3.15
- Test only Python 3.9 and 3.15
- Add auto-deployment for docs
- Fix dev docs
- Bump version to 1.36.1

### ◀️ Revert

- Use Python 3.14 instead of 3.15
## [1.36.0] - 2025-11-03

### 🚀 Features

- Add --preset option and update docs

### 🐛 Bug Fixes

- Correct markdown indentation for MkDocs Material
- Warn instead of debug on invalid preset options

### 📚 Documentation

- Synchronize "What's New" section between README and docs
- Update
- Fix formatting
- Update documentation for new features

### ⚙️ Miscellaneous Tasks

- Bump version to 1.36.0
## [1.35.0] - 2025-10-30

### 🚀 Features

- Batch mode normalization

### 🐛 Bug Fixes

- Update completions

### 📚 Documentation

- Update readme and docs
- How to generate completions
- Fix completion links and update manual completions
- Add link to GH repo

### ⚙️ Miscellaneous Tasks

- Add GitHub Actions workflow for automatic docs deployment
- Update claude.md
- Bump version to 1.35.0
## [1.34.0] - 2025-10-21

### 🚀 Features

- Add selective audio stream normalization (#295)

### 📚 Documentation

- Fix Docker Hub badge link in README

### ⚙️ Miscellaneous Tasks

- Update ffmpeg version
- Update claude.md
- Bump version to 1.34.0
## [1.33.4] - 2025-10-18

### 🐛 Bug Fixes

- Apply extra input options to first pass, fixes #294

### 📚 Documentation

- Update intro

### ⚙️ Miscellaneous Tasks

- Bump version to 1.33.4
## [1.33.3] - 2025-10-17

### ⚙️ Miscellaneous Tasks

- Remove old gitchangelog templates
- Add python 3.14 support, remove old license classifier
- Bump version to 1.33.3
## [1.33.2] - 2025-10-16

### 🐛 Bug Fixes

- Bug when first pass stats are skipped

### 📚 Documentation

- Document --lower-only option

### ⚙️ Miscellaneous Tasks

- Add commitizen for conventional commits
- Bump version to 1.33.2
## [1.33.0] - 2025-08-22

### 📚 Documentation

- Add @georgev93 as a contributor
- Add @odie5533 as a contributor

### ⚙️ Miscellaneous Tasks

- Skip ci tests for commits that change only markdown files (#291)
## [1.32.2] - 2025-05-08

### 🐛 Bug Fixes

- Make replaygain use second pass stats

### 📚 Documentation

- Reference changelog
## [1.32.1] - 2025-05-08

### 📚 Documentation

- Docs
## [1.32.0] - 2025-05-07

### 🐛 Bug Fixes

- Flake8 no longer used
- Do not write replaygain tags if dry run is used

### 📚 Documentation

- Update ffmpeg guide
- Convert options to headlines
- Update contributing guide
## [1.31.2] - 2025-03-19

### 🐛 Bug Fixes

- Special handling of /dev/null
## [1.31.0] - 2024-12-15

### 🚀 Features

- Add completions

### 📚 Documentation

- Update docs to include lower-only
- Update explainer
## [1.30.0] - 2024-11-22

### 💼 Other

- `--print-stats` only outputs the last stream

### 📚 Documentation

- Add @ahmetsait as a contributor
## [1.29.2] - 2024-11-18

### 🐛 Bug Fixes

- Show percentage with two decimal digits in progress

### ⚙️ Miscellaneous Tasks

- Add python 12
## [1.29.1] - 2024-10-22

### 🐛 Bug Fixes

- Override argparse usage
## [1.28.3] - 2024-08-16

### 📚 Documentation

- Add @kanjieater as a contributor
## [1.27.4] - 2023-06-29

### 🐛 Bug Fixes

- Dockerfile used wrong path

### 📚 Documentation

- Add @sian1468 as a contributor
- Add psavva as a contributor for code (#236)
- Add HighMans as a contributor for code (#242)
## [1.27.2] - 2023-05-05

### 📚 Documentation

- Add @07416 as a contributor
## [1.27.1] - 2023-04-25

### 📚 Documentation

- Add @mjhalwa as a contributor
## [1.27.0] - 2023-04-24

### 🚀 Features

- Add linear loudnorm option to set lra up to target, then keep input lra
## [1.26.3] - 2023-02-08

### 📚 Documentation

- Add @g3n35i5 as a contributor
## [1.26.2] - 2023-02-06

### 🚜 Refactor

- Improved logging behavior (#216)
## [1.26.0] - 2022-12-14

### 📚 Documentation

- Add @benjaoming as a contributor
- Add @Geekfish as a contributor
- Add @thenewguy as a contributor
- Add @aviolo as a contributor
- Add @jetpks as a contributor
- Add @kostalski as a contributor
- Add @justinpearson as a contributor
- Add @Nottt as a contributor
- Add @Mathijsz as a contributor
- Add @mpuels as a contributor
- Add @mvbattista as a contributor
- Add WyattBlue as a contributor for code (#198)
## [1.22.0] - 2021-03-09

### 💼 Other

- New tests
## [1.3.0] - 2018-04-15

### 💼 Other

- Progress bar
## [1.0.0] - 2018-01-23

### 💼 Other

- V1.0 rewrite
## [0.1.3] - 2015-12-15

==> ffmpeg-normalize-dmo_1.37.3.orig.tar.xz: ffmpeg-normalize-1.37.3/CHANGELOG.md <==
## [1.37.3] - 2026-02-08

### 🐛 Bug Fixes

- Restore uv/ffmpeg setup and allowed tools in CI workflows
- Restore write permissions for Claude CI workflows
- Strip ReplayGain tags after normalization, fixes #308

### ⚙️ Miscellaneous Tasks

- Bump version to 1.37.3
## [1.37.2] - 2026-02-04

### 🚀 Features

- Better preset listing

### ⚙️ Miscellaneous Tasks

- Bump version to 1.37.2
## [1.37.1] - 2026-02-04

### ⚙️ Miscellaneous Tasks

- Bump version to 1.37.1
## [1.37.0] - 2026-02-03

### 🐛 Bug Fixes

- Update Claude workflows for fork PR permissions

### 📚 Documentation

- Update API examples

### ⚙️ Miscellaneous Tasks

- Update contriburors
- Bump version to 1.37.0
## [1.36.1] - 2026-01-07

### 🚀 Features

- Better file validation

### 📚 Documentation

- Typo
- Move quickstart before what's new section

### ⚙️ Miscellaneous Tasks

- Update support to python 3.15
- Test only Python 3.9 and 3.15
- Add auto-deployment for docs
- Fix dev docs
- Bump version to 1.36.1

### ◀️ Revert

- Use Python 3.14 instead of 3.15
## [1.36.0] - 2025-11-03

### 🚀 Features

- Add --preset option and update docs

### 🐛 Bug Fixes

- Correct markdown indentation for MkDocs Material
- Warn instead of debug on invalid preset options

### 📚 Documentation

- Synchronize "What's New" section between README and docs
- Update
- Fix formatting
- Update documentation for new features

### ⚙️ Miscellaneous Tasks

- Bump version to 1.36.0
## [1.35.0] - 2025-10-30

### 🚀 Features

- Batch mode normalization

### 🐛 Bug Fixes

- Update completions

### 📚 Documentation

- Update readme and docs
- How to generate completions
- Fix completion links and update manual completions
- Add link to GH repo

### ⚙️ Miscellaneous Tasks

- Add GitHub Actions workflow for automatic docs deployment
- Update claude.md
- Bump version to 1.35.0
## [1.34.0] - 2025-10-21

### 🚀 Features

- Add selective audio stream normalization (#295)

### 📚 Documentation

- Fix Docker Hub badge link in README

### ⚙️ Miscellaneous Tasks

- Update ffmpeg version
- Update claude.md
- Bump version to 1.34.0
## [1.33.4] - 2025-10-18

### 🐛 Bug Fixes

- Apply extra input options to first pass, fixes #294

### 📚 Documentation

- Update intro

### ⚙️ Miscellaneous Tasks

- Bump version to 1.33.4
## [1.33.3] - 2025-10-17

### ⚙️ Miscellaneous Tasks

- Remove old gitchangelog templates
- Add python 3.14 support, remove old license classifier
- Bump version to 1.33.3
## [1.33.2] - 2025-10-16

### 🐛 Bug Fixes

- Bug when first pass stats are skipped

### 📚 Documentation

- Document --lower-only option

### ⚙️ Miscellaneous Tasks

- Add commitizen for conventional commits
- Bump version to 1.33.2
## [1.33.0] - 2025-08-22

### 📚 Documentation

- Add @georgev93 as a contributor
- Add @odie5533 as a contributor

### ⚙️ Miscellaneous Tasks

- Skip ci tests for commits that change only markdown files (#291)
## [1.32.2] - 2025-05-08

### 🐛 Bug Fixes

- Make replaygain use second pass stats

### 📚 Documentation

- Reference changelog
## [1.32.1] - 2025-05-08

### 📚 Documentation

- Docs
## [1.32.0] - 2025-05-07

### 🐛 Bug Fixes

- Flake8 no longer used
- Do not write replaygain tags if dry run is used

### 📚 Documentation

- Update ffmpeg guide
- Convert options to headlines
- Update contributing guide
## [1.31.2] - 2025-03-19

### 🐛 Bug Fixes

- Special handling of /dev/null
## [1.31.0] - 2024-12-15

### 🚀 Features

- Add completions

### 📚 Documentation

- Update docs to include lower-only
- Update explainer
## [1.30.0] - 2024-11-22

### 💼 Other

- `--print-stats` only outputs the last stream

### 📚 Documentation

- Add @ahmetsait as a contributor
## [1.29.2] - 2024-11-18

### 🐛 Bug Fixes

- Show percentage with two decimal digits in progress

### ⚙️ Miscellaneous Tasks

- Add python 12
## [1.29.1] - 2024-10-22

### 🐛 Bug Fixes

- Override argparse usage
## [1.28.3] - 2024-08-16

### 📚 Documentation

- Add @kanjieater as a contributor
## [1.27.4] - 2023-06-29

### 🐛 Bug Fixes

- Dockerfile used wrong path

### 📚 Documentation

- Add @sian1468 as a contributor
- Add psavva as a contributor for code (#236)
- Add HighMans as a contributor for code (#242)
## [1.27.2] - 2023-05-05

### 📚 Documentation

- Add @07416 as a contributor
## [1.27.1] - 2023-04-25

### 📚 Documentation

- Add @mjhalwa as a contributor
## [1.27.0] - 2023-04-24

### 🚀 Features

- Add linear loudnorm option to set lra up to target, then keep input lra
## [1.26.3] - 2023-02-08

### 📚 Documentation

- Add @g3n35i5 as a contributor
## [1.26.2] - 2023-02-06

### 🚜 Refactor

- Improved logging behavior (#216)
## [1.26.0] - 2022-12-14

### 📚 Documentation

- Add @benjaoming as a contributor
- Add @Geekfish as a contributor
- Add @thenewguy as a contributor
- Add @aviolo as a contributor
- Add @jetpks as a contributor
- Add @kostalski as a contributor
- Add @justinpearson as a contributor
- Add @Nottt as a contributor
- Add @Mathijsz as a contributor
- Add @mpuels as a contributor
- Add @mvbattista as a contributor
- Add WyattBlue as a contributor for code (#198)
## [1.22.0] - 2021-03-09

### 💼 Other

- New tests
## [1.3.0] - 2018-04-15

### 💼 Other

- Progress bar
## [1.0.0] - 2018-01-23

### 💼 Other

- V1.0 rewrite
## [0.1.3] - 2015-12-15
